import { Component, Input, HostListener, ChangeDetectorRef, OnDestroy, OnInit } from '@angular/core';
import { ResumableFileUploadService, File } from './resumable-file-upload.service';
import { Subscription } from 'rxjs';


@Component({
    selector: 'resumable-file-upload',
    templateUrl: './resumable-file-upload.component.html',
    styleUrls: ['./resumable-file-upload.component.scss']
})

export class ResumableFileUploadComponent implements OnInit, OnDestroy {

  @Input('parentCode')
  set parentCode(parentCode: string) {
    if (parentCode && parentCode != "null" && parentCode != "")
      this.uploadService.parentCode = parentCode;
    else
      this.uploadService.parentCode = null;
  }           

    constructor(private cd: ChangeDetectorRef, public uploadService: ResumableFileUploadService) {
    }

    private refreshSub: Subscription;

    ngOnInit() {
      this.uploadService.init();
      this.refreshSub = this.uploadService.refresh.subscribe((e: any) => {
        this.cd.markForCheck();
      });  
    }

    ngOnDestroy() {
      if(this.refreshSub) this.refreshSub.unsubscribe();
    }

    //TODO do this with an canunload guard
    @HostListener('window:beforeunload')
    windowBeforeUnload = function () {
        if (this.uploadService.isUploading) {
            return false;
        }
    }        
}
